#include <stdio.h>
#include <string.h>

int main()
{
	char seq[ 1000 ];
	int i, total, len;

	printf("Enter DNA sequences\n");
	while ( scanf("%s", seq) == 1)
	{
		total = 0;
		len = strlen(seq);
		for( i=0 ; i < len - 1 ; i++)
		{
			if( seq[ i ] == 'A' && seq[ i + 1 ] == 'T')
			{
				total++;
			}
		}
	printf("The total number of ATs is %d\n", total);
	}

}

