#include <stdio.h>
#include <string.h>

int main()
{
	char seq[ 1000 ];
	int  len, i;
	int  looks_dna;

	while( scanf("%s", seq) == 1)
	{
		looks_dna = 1;
		len = strlen(seq);

		for( i=0 ; i < len ; i++)
		{
			if( seq[i] != 'A' &&
				seq[i] != 'T' &&
				seq[i] != 'G' &&
				seq[i] != 'C')
				{
					looks_dna = 0;
				}
		}

		if( looks_dna == 1)
			{
				printf("This looks like a nucleotide sequence.\n");
			}
		else
			{
				printf("This looks like a protein sequence.\n");
			}
	}

}
