#include <stdio.h>
#include <string.h>
#include <stdlib.h>

int main()
{
	char seq[ 1000 ];
	int  L;

	if( scanf("%s", seq) != 1)
		{
			printf("DNA sequence expected. Abort.\n");
			exit( 1 );
		}

	L = strlen( seq );

	if (
		   ( seq[  0] == 'A' && seq[  1] == 'T' && seq[  2] == 'G' )

										&&

		   ( ( seq[L-3] == 'T' && seq[L-2] == 'A' && seq[L-1] == 'A' ) ||
		     ( seq[L-3] == 'T' && seq[L-2] == 'A' && seq[L-1] == 'G' ) ||
		     ( seq[L-3] == 'T' && seq[L-2] == 'G' && seq[L-1] == 'A' )    )

										&&
		   L % 3 == 0
	   )
			{
				printf("This looks like a prokaryotic coding sequence !\n");
			}
	else
			{
				printf("This doesn't look like a prokaryotic coding sequence.\n");
			}
}

